@@ -1,17 +1,15 @@
-#! /usr/local/bin/perl
-
-#makes things work when run without install
-use lib qw( ../perl-shared/blib/lib ../perl-shared/blib/arch );
+#! /usr/bin/perl
 # this is for after install
-use lib qw( /usr/local/lib/perl ../lib/perl );
+use lib qw( /usr/local/lib/perl );
 
 use RRDs;
 my $start=time;
 my $rrd="randome.rrd";
 my $name = $0;
+$name =~ s/.*\///g;
 $name =~ s/\.pl.*//g;
 
-RRDs::create ($rrd, "--start",$start-1, "--step",290,
+RRDs::create ($rrd, "--start",$start-1, "--step",300,
 	      "DS:a:GAUGE:600:U:U",
 	      "DS:b:GAUGE:600:U:U",
 	      "RRA:AVERAGE:0.5:1:300");
@@ -31,7 +29,7 @@ RRDs::graph "$name.png",
   "--title", uc($name)." Demo", 
   "--start", "$start + 1 h",
   "--end", "start + 1000 min",
-  "--interlace", 
+  "--interlaced",
   "--imgformat","PNG",
   "--width=450",
   "DEF:a=$rrd:a:AVERAGE",
@@ -44,7 +42,7 @@ RRDs::graph "$name.png",
 ;
 
 if ($ERROR = RRDs::error) {
-  print "ERROR: $ERROR\n";
+  die "ERROR: $ERROR\n";
 };
 
 
