@@ -32,7 +32,7 @@ RRDs::graph "$name.png",
   "--start", "now",
   "--end", "start+1d",
   "--lower-limit=0",
-  "--interlace", 
+  "--interlaced",
   "--imgformat","PNG",
   "--width=450",
   "DEF:a=$rrd:a:AVERAGE",
