@@ -1,17 +1,12 @@
 #! /usr/bin/perl
-
-#makes things work when run without install
-use lib qw( ../perl-shared/blib/lib ../perl-shared/blib/arch );
-
-#makes programm work AFTER install
-use lib qw( /usr/local/lib/perl ../lib/perl );
+use lib qw( /usr/local/lib/perl );
 
 use strict;
 use vars qw(@ISA $loaded);
 
 use RRDs;
 my $start=time;
-my $rrd="randome.rrd";
+my $rrd="random.rrd";
 RRDs::create ($rrd, "--start",$start-1, "--step",300,
 	      "DS:a:GAUGE:600:U:U",
 	      "DS:b:GAUGE:600:U:U",
@@ -26,10 +21,10 @@ for ($t=$start; $t<$start+200*300; $t+=300){
   }
 }
 RRDs::graph "stripes.png",
-  "--title", 'Stripes Demo', 
+  "--title", "Stripes Demo", 
   "--start", $start,
   "--end", "start + 400 min",
-  "--interlace", 
+  "--interlaced",
   "--imgformat","PNG",
   "--width=450",
   "DEF:a=$rrd:a:AVERAGE",
@@ -40,10 +35,10 @@ RRDs::graph "stripes.png",
   "AREA:beta#00b674:beta",
   "LINE1:b#ff4400:beta envelope\\c",
   "COMMENT:\\s",
-  "COMMENT:CDEF\:alpha=TIME,1200,%,600,LT,a,UNKN,IF",
-  "COMMENT:CDEF\:beta=TIME,1200,%,600,GE,b,UNKN,IF\\j";
+  "COMMENT:alpha=TIME,1200,%,600,LT,a,UNKN,IF",
+  "COMMENT:beta=TIME,1200,%,600,GE,b,UNKN,IF\\j";
 if ($ERROR = RRDs::error) {
-  print "ERROR: $ERROR\n";
+  die "ERROR: $ERROR\n";
 };
 
 
